import { request } from "../lib/api";

const MEETINGS_URL = "https://api.videosdk.live/v2";
export let meetingToken: string;

export const getToken = async () => {
  if (meetingToken) {
    return meetingToken;
  } else {
    try {
      const data: { token: string } = await MeetingsAPI.getToken();
      meetingToken = data.token;
      return data.token;
    } catch (error) {}
  }
};

export default class MeetingsAPI {
  static getToken = (): Promise<any> =>
    request("<BASE_URL>/auth/conference/key", "GET", {}, false, undefined);

  static createRoom = async (customRoomId: string) =>
    request(
      `${MEETINGS_URL}/rooms`,
      "POST",
      { customRoomId },
      false,
      undefined,
      { Authorization: await getToken() }
    );

  static endSession = async (roomId: string) =>
    request(
      `${MEETINGS_URL}/sessions/end`,
      "POST",
      { roomId },
      false,
      undefined,
      { Authorization: await getToken() }
    );

  static deactivateRoom = async (roomId: string) =>
    request(
      `${MEETINGS_URL}/rooms/deactivate`,
      "POST",
      { roomId },
      false,
      undefined,
      { Authorization: await getToken() }
    );

  static startRecord = async (roomId: string) =>
    request(
      `${MEETINGS_URL}/recordings/start`,
      "POST",
      { roomId },
      false,
      undefined,
      { Authorization: await getToken() }
    );

  static getRecordings = async (roomId: string) =>
    request(`${MEETINGS_URL}/recordings`, "GET", { roomId }, false, undefined, {
      Authorization: await getToken(),
    });
}
