import React, { useState, useRef } from "react";
import { useDispatch } from "react-redux";
import { useNavigate } from "react-router-dom";
import { signIn } from "../common/actions/auth";
import { keyEvent } from "../common/lib/util";
import { KeyDetails, SignInPayload, USER_TYPE } from "../common/types";

type OwnProps = {
  setAlert: (alert: string) => void;
  userType: USER_TYPE;
};

const Login = ({ userType, setAlert }: OwnProps) => {
  const dispatch = useDispatch();
  const navigate = useNavigate();
  const [credentials, setCredentials] = useState({
    email: "",
    password: "",
  });

  const keyCount = useRef<number>(0);
  const keydownArray = useRef<KeyDetails[]>([]);
  const keyupArray = useRef<KeyDetails[]>([]);

  const onChangeCredentials = (e: React.ChangeEvent<HTMLInputElement>) => {
    setCredentials({ ...credentials, [e.target.name]: e.target.value });
  };

  const clearData = () => {
    setCredentials({ ...credentials, password: "" });
    keyCount.current = 0;
    keydownArray.current = [];
    keyupArray.current = [];
  };

  const submit = () => {
    const data: SignInPayload = {
      email: credentials.email,
      password: credentials.password,
      keydown: keydownArray.current,
      keyup: keyupArray.current,
      userType,
    };
    clearData();
    dispatch(
      signIn(data, (state) => {
        if (state === "failed") {
          setAlert("Attempt failed! Try again");
        } else {
          navigate("/home");
        }
      })
    );
  };

  const onKeyDown = (e: any) => {
    const details = keyEvent(e);
    if (!details) return;

    if (
      ["Backspace"].includes(details.code) ||
      ["Backspace"].includes(details.code)
    ) {
      return clearData();
    }

    keydownArray.current.push(details);
    keyupArray.current.push({ ...details, time: null });
    keyCount.current++;
  };

  const onKeyUp = (e: any) => {
    const details = keyEvent(e);
    if (!details) return;
    if (!details.time) details.time = Date.now();

    if (
      ["Backspace"].includes(details.code) ||
      ["Backspace"].includes(details.code)
    ) {
      return clearData();
    }

    var reqdUpKeystroke = keyupArray.current.find(
      (element) => element.code === details.code && !element.time
    );

    if (reqdUpKeystroke) reqdUpKeystroke.time = details.time;

    if (details.code === "Enter") submit();
  };

  const disable = credentials.email === "" || credentials.password === "";

  return (
    <>
      <h5 className="card-title">Sign in</h5>
      <div className="mb-3">
        <label htmlFor="exampleFormControlInput1" className="form-label">
          Email
        </label>
        <input
          className="form-control"
          type="email"
          aria-label=".form-control-lg example"
          name="email"
          onChange={onChangeCredentials}
        />
      </div>

      <div className="mb-3">
        <label htmlFor="exampleFormControlInput1" className="form-label">
          Password
        </label>
        <input
          className="form-control"
          type="password"
          aria-label=".form-control-lg example"
          name="password"
          id="password"
          onChange={onChangeCredentials}
          onKeyDown={onKeyDown}
          onKeyUp={onKeyUp}
        />
      </div>
      <button
        type="button"
        className="btn btn-primary"
        onClick={submit}
        disabled={disable}
      >
        Login
      </button>
    </>
  );
};

export default Login;
