import React from "react";
import Modal from "react-modal";

type OwnProps = {
  isOpen: boolean;
  onRequestClose: () => void;
  children: JSX.Element | JSX.Element[];
  size?: "md" | "lg";
  shouldCloseOnOverlayClick?: boolean;
};

const CustomModal = ({
  isOpen,
  onRequestClose,
  children,
  size = "md",
  shouldCloseOnOverlayClick = true,
}: OwnProps) => {
  const width = size === "md" ? "400px" : "600px";
  return (
    <Modal
      isOpen={isOpen}
      ariaHideApp={false}
      onRequestClose={onRequestClose}
      closeTimeoutMS={300}
      shouldCloseOnOverlayClick={shouldCloseOnOverlayClick}
      style={{
        overlay: {
          backgroundColor: "rgba(0, 0, 0, 0.5)",
        },
        content: {
          width,
          top: "50%",
          left: "50%",
          right: "auto",
          bottom: "auto",
          marginRight: "-50%",
          transform: "translate(-50%, -50%)",
          maxHeight: "95%",
        },
      }}
    >
      {children}
    </Modal>
  );
};

export default CustomModal;
