import React, { useRef, useState } from "react";
import { getDownloadURL, ref, uploadBytesResumable } from "firebase/storage";
import Cropper, { Area } from "react-easy-crop";
import getCroppedImg from "../../common/lib/crop";
import { fileStorage } from "../../common/config";
import { USER_TYPE } from "../../common/types";

type OwnProps = {
  onRequestClose: () => void;
  profilePicPrev: string | null;
  userId?: string;
  onUpdateCandidate: (update: any) => void;
  userType: USER_TYPE;
};

const ProfilePicCrop = ({
  onRequestClose,
  profilePicPrev,
  userId,
  onUpdateCandidate,
  userType,
}: OwnProps) => {
  const [progress, setprogress] = useState(0);
  const [crop, setCrop] = useState({ x: 0, y: 0 });
  const [zoom, setZoom] = useState(1);
  const _croppedAreaPixels = useRef<Area>();
  if (!profilePicPrev) return null;

  const onCropComplete = (croppedArea: Area, croppedAreaPixels: Area) => {
    _croppedAreaPixels.current = croppedAreaPixels;
  };

  const onChangeZoom = (e: React.ChangeEvent<HTMLInputElement>) => {
    setZoom(Number(e.target.value));
  };

  const onPressSelect = async () => {
    if (_croppedAreaPixels.current) {
      const { file }: any = await getCroppedImg(
        profilePicPrev,
        _croppedAreaPixels.current
      );

      const extension = file.name.split(".")[1];

      const uploadRef = ref(fileStorage, `/${userType}/${userId}.${extension}`);
      const uploadTask = uploadBytesResumable(uploadRef, file);

      uploadTask.on(
        "state_changed",
        (snapshot) => {
          const percent = Math.round(
            (snapshot.bytesTransferred / snapshot.totalBytes) * 100
          );
          setprogress(percent);
        },
        (err) => {},
        () => {
          getDownloadURL(uploadTask.snapshot.ref).then((url) => {
            setprogress(0);
            onUpdateCandidate({ profilePicture: url });
            onRequestClose();
          });
        }
      );
    }
  };

  return (
    <div
      style={{
        position: "absolute",
        top: "0",
        left: "0",
        right: "0",
        bottom: "0",
      }}
    >
      <Cropper
        image={profilePicPrev}
        crop={crop}
        zoom={zoom}
        aspect={1}
        onCropChange={setCrop}
        onCropComplete={onCropComplete}
        onZoomChange={setZoom}
        style={{
          containerStyle: {
            backgroundColor: "white",
            borderRadius: "15px",
          },
        }}
      />

      <div
        style={{
          position: "absolute",
          bottom: "0",
          height: "80px",
          background: "white",
          width: "100%",
          borderBottomLeftRadius: "15px",
          borderBottomRightRadius: "15px",
          padding: "0 20px",
        }}
      >
        {progress > 0 && (
          <div className="progress  ">
            <div
              className="progress-bar progress-bar-striped"
              style={{ width: `${progress}%` }}
            ></div>
          </div>
        )}

        <div className="row mt-4">
          <div className="col-6">
            <input
              type="range"
              min={1}
              max={10}
              onChange={onChangeZoom}
              className="form-range"
            />
          </div>
          <div className="col-auto">
            <button
              type="button"
              className="btn btn-warning btn-sm"
              onClick={onPressSelect}
            >
              Crop & select picture
            </button>
          </div>
          <div className="col-auto">
            <button
              type="button"
              className="btn btn-secondary btn-sm"
              onClick={onRequestClose}
            >
              Cancel
            </button>
          </div>
        </div>
      </div>
    </div>
  );
};

export default ProfilePicCrop;
