import React, { useState, useEffect } from "react";
import { useNavigate, useSearchParams } from "react-router-dom";
import Meeting from "../components/Meeting";
import { getToken } from "../common/apis/meetings";

const MeetingRoom = () => {
  const navigate = useNavigate();
  const [isReady, setIsReady] = useState<boolean>(false);
  const [searchParams] = useSearchParams();
  const roomId = searchParams.get("roomId");

  useEffect(() => {
    if (roomId && roomId !== "ended") {
      getReady();
    }
  }, [roomId]);

  const getReady = async () => {
    try {
      await getToken();
      setIsReady(true);
    } catch (error) {}
  };

  const onMeetingLeave = () => {
    navigate("/home");
  };

  if (!roomId) {
    return null;
  } else if (roomId === "ended") {
    return (
      <div className="card p-4">
        <div className="interview-room">
          <p>This session has ended!</p>
        </div>
      </div>
    );
  } else {
    if (isReady) {
      return (
        <div className="card p-4">
          <div className="interview-room">
            <Meeting
              roomId={roomId}
              onMeetingLeave={onMeetingLeave}
              record={false}
            />
          </div>
        </div>
      );
    } else {
      return (
        <div className="card p-4">
          <div className="interview-room">
            <p>Loading...</p>
          </div>
        </div>
      );
    }
  }
};

export default MeetingRoom;
